@@ -782,297 +782,494 @@ rainbow = Colormap((0.000, (0.0, 0.0, 0.5)),
 # * Colors from www.ColorBrewer.org by Cynthia A. Brewer, Geography,
 # * Pennsylvania State University.
 
-# * Single hue *
+# * Sequential Colormaps *
 
-blues = Colormap((0.000, (247 / 255.0, 251 / 255.0, 1.0)),
-                 (1.000, (8 / 255.0, 48 / 255.0, 107 / 255.0)))
+blues = Colormap(
+    (0 / 8, (247 / 255, 251 / 255, 255 / 255)),
+    (1 / 8, (222 / 255, 235 / 255, 247 / 255)),
+    (2 / 8, (198 / 255, 219 / 255, 239 / 255)),
+    (3 / 8, (158 / 255, 202 / 255, 225 / 255)),
+    (4 / 8, (107 / 255, 174 / 255, 214 / 255)),
+    (5 / 8, (66 / 255, 146 / 255, 198 / 255)),
+    (6 / 8, (33 / 255, 113 / 255, 181 / 255)),
+    (7 / 8, (8 / 255, 81 / 255, 156 / 255)),
+    (8 / 8, (8 / 255, 48 / 255, 107 / 255)),
+)
 
-greens = Colormap((0.000, (247 / 255.0, 252 / 255.0, 245 / 255.0)),
-                  (1.000, (0.0, 68 / 255.0, 27 / 255.0)))
+bugn = Colormap(
+    (0 / 8, (247 / 255, 252 / 255, 253 / 255)),
+    (1 / 8, (229 / 255, 245 / 255, 249 / 255)),
+    (2 / 8, (204 / 255, 236 / 255, 230 / 255)),
+    (3 / 8, (153 / 255, 216 / 255, 201 / 255)),
+    (4 / 8, (102 / 255, 194 / 255, 164 / 255)),
+    (5 / 8, (65 / 255, 174 / 255, 118 / 255)),
+    (6 / 8, (35 / 255, 139 / 255, 69 / 255)),
+    (7 / 8, (0 / 255, 109 / 255, 44 / 255)),
+    (8 / 8, (0 / 255, 68 / 255, 27 / 255)),
+)
 
-greys = Colormap((0.0, (1.0, 1.0, 1.0)),
-                 (1.0, (0.0, 0.0, 0.0)))
+bupu = Colormap(
+    (0 / 8, (247 / 255, 252 / 255, 253 / 255)),
+    (1 / 8, (224 / 255, 236 / 255, 244 / 255)),
+    (2 / 8, (191 / 255, 211 / 255, 230 / 255)),
+    (3 / 8, (158 / 255, 188 / 255, 218 / 255)),
+    (4 / 8, (140 / 255, 150 / 255, 198 / 255)),
+    (5 / 8, (140 / 255, 107 / 255, 177 / 255)),
+    (6 / 8, (136 / 255, 65 / 255, 157 / 255)),
+    (7 / 8, (129 / 255, 15 / 255, 124 / 255)),
+    (8 / 8, (77 / 255, 0 / 255, 75 / 255)),
+)
 
-oranges = Colormap((0.0, (1.0, 245 / 255.0, 235 / 255.0)),
-                   (1.0, (127 / 255.0, 39 / 255.0, 4 / 255.0)))
+gnbu = Colormap(
+    (0 / 8, (247 / 255, 252 / 255, 240 / 255)),
+    (1 / 8, (224 / 255, 243 / 255, 219 / 255)),
+    (2 / 8, (204 / 255, 235 / 255, 197 / 255)),
+    (3 / 8, (168 / 255, 221 / 255, 181 / 255)),
+    (4 / 8, (123 / 255, 204 / 255, 196 / 255)),
+    (5 / 8, (78 / 255, 179 / 255, 211 / 255)),
+    (6 / 8, (43 / 255, 140 / 255, 190 / 255)),
+    (7 / 8, (8 / 255, 104 / 255, 172 / 255)),
+    (8 / 8, (8 / 255, 64 / 255, 129 / 255)),
+)
 
-purples = Colormap((0.0, (252 / 255.0, 251 / 255.0, 253 / 255.0)),
-                   (1.0, (63 / 255.0, 0.0, 125 / 255.0)))
+greens = Colormap(
+    (0 / 8, (247 / 255, 252 / 255, 245 / 255)),
+    (1 / 8, (229 / 255, 245 / 255, 224 / 255)),
+    (2 / 8, (199 / 255, 233 / 255, 192 / 255)),
+    (3 / 8, (161 / 255, 217 / 255, 155 / 255)),
+    (4 / 8, (116 / 255, 196 / 255, 118 / 255)),
+    (5 / 8, (65 / 255, 171 / 255, 93 / 255)),
+    (6 / 8, (35 / 255, 139 / 255, 69 / 255)),
+    (7 / 8, (0 / 255, 109 / 255, 44 / 255)),
+    (8 / 8, (0 / 255, 68 / 255, 27 / 255)),
+)
 
-reds = Colormap((0.0, (1.0, 245 / 255.0, 240 / 255.0)),
-                (1.0, (103 / 255.0, 0.0, 13 / 255.0)))
+greys = Colormap(
+    (0 / 8, (255 / 255, 255 / 255, 255 / 255)),
+    (1 / 8, (240 / 255, 240 / 255, 240 / 255)),
+    (2 / 8, (217 / 255, 217 / 255, 217 / 255)),
+    (3 / 8, (189 / 255, 189 / 255, 189 / 255)),
+    (4 / 8, (150 / 255, 150 / 255, 150 / 255)),
+    (5 / 8, (115 / 255, 115 / 255, 115 / 255)),
+    (6 / 8, (82 / 255, 82 / 255, 82 / 255)),
+    (7 / 8, (37 / 255, 37 / 255, 37 / 255)),
+    (8 / 8, (0 / 255, 0 / 255, 0 / 255)),
+)
 
-# * Multihue *
+oranges = Colormap(
+    (0 / 8, (255 / 255, 245 / 255, 235 / 255)),
+    (1 / 8, (254 / 255, 230 / 255, 206 / 255)),
+    (2 / 8, (253 / 255, 208 / 255, 162 / 255)),
+    (3 / 8, (253 / 255, 174 / 255, 107 / 255)),
+    (4 / 8, (253 / 255, 141 / 255, 60 / 255)),
+    (5 / 8, (241 / 255, 105 / 255, 19 / 255)),
+    (6 / 8, (217 / 255, 72 / 255, 1 / 255)),
+    (7 / 8, (166 / 255, 54 / 255, 3 / 255)),
+    (8 / 8, (127 / 255, 39 / 255, 4 / 255)),
+)
 
-# BuGn
+orrd = Colormap(
+    (0 / 8, (255 / 255, 247 / 255, 236 / 255)),
+    (1 / 8, (254 / 255, 232 / 255, 200 / 255)),
+    (2 / 8, (253 / 255, 212 / 255, 158 / 255)),
+    (3 / 8, (253 / 255, 187 / 255, 132 / 255)),
+    (4 / 8, (252 / 255, 141 / 255, 89 / 255)),
+    (5 / 8, (239 / 255, 101 / 255, 72 / 255)),
+    (6 / 8, (215 / 255, 48 / 255, 31 / 255)),
+    (7 / 8, (179 / 255, 0 / 255, 0 / 255)),
+    (8 / 8, (127 / 255, 0 / 255, 0 / 255)),
+)
 
-bugn = Colormap((0.000, (247 / 255.0, 252 / 255.0, 253 / 255.0)),
-                (1.000, (0.0, 68 / 255.0, 27 / 255.0)))
+pubu = Colormap(
+    (0 / 8, (255 / 255, 247 / 255, 251 / 255)),
+    (1 / 8, (236 / 255, 231 / 255, 242 / 255)),
+    (2 / 8, (208 / 255, 209 / 255, 230 / 255)),
+    (3 / 8, (166 / 255, 189 / 255, 219 / 255)),
+    (4 / 8, (116 / 255, 169 / 255, 207 / 255)),
+    (5 / 8, (54 / 255, 144 / 255, 192 / 255)),
+    (6 / 8, (5 / 255, 112 / 255, 176 / 255)),
+    (7 / 8, (4 / 255, 90 / 255, 141 / 255)),
+    (8 / 8, (2 / 255, 56 / 255, 88 / 255)),
+)
 
-# BuPu
+pubugn = Colormap(
+    (0 / 8, (255 / 255, 247 / 255, 251 / 255)),
+    (1 / 8, (236 / 255, 226 / 255, 240 / 255)),
+    (2 / 8, (208 / 255, 209 / 255, 230 / 255)),
+    (3 / 8, (166 / 255, 189 / 255, 219 / 255)),
+    (4 / 8, (103 / 255, 169 / 255, 207 / 255)),
+    (5 / 8, (54 / 255, 144 / 255, 192 / 255)),
+    (6 / 8, (2 / 255, 129 / 255, 138 / 255)),
+    (7 / 8, (1 / 255, 108 / 255, 89 / 255)),
+    (8 / 8, (1 / 255, 70 / 255, 54 / 255)),
+)
 
-bupu = Colormap((0.000, (247 / 255.0, 252 / 255.0, 253 / 255.0)),
-                (1.000, (77 / 255.0, 0.0, 75 / 255.0)))
+purd = Colormap(
+    (0 / 8, (247 / 255, 244 / 255, 249 / 255)),
+    (1 / 8, (231 / 255, 225 / 255, 239 / 255)),
+    (2 / 8, (212 / 255, 185 / 255, 218 / 255)),
+    (3 / 8, (201 / 255, 148 / 255, 199 / 255)),
+    (4 / 8, (223 / 255, 101 / 255, 176 / 255)),
+    (5 / 8, (231 / 255, 41 / 255, 138 / 255)),
+    (6 / 8, (206 / 255, 18 / 255, 86 / 255)),
+    (7 / 8, (152 / 255, 0 / 255, 67 / 255)),
+    (8 / 8, (103 / 255, 0 / 255, 31 / 255)),
+)
 
-# GnBu
+purples = Colormap(
+    (0 / 8, (252 / 255, 251 / 255, 253 / 255)),
+    (1 / 8, (239 / 255, 237 / 255, 245 / 255)),
+    (2 / 8, (218 / 255, 218 / 255, 235 / 255)),
+    (3 / 8, (188 / 255, 189 / 255, 220 / 255)),
+    (4 / 8, (158 / 255, 154 / 255, 200 / 255)),
+    (5 / 8, (128 / 255, 125 / 255, 186 / 255)),
+    (6 / 8, (106 / 255, 81 / 255, 163 / 255)),
+    (7 / 8, (84 / 255, 39 / 255, 143 / 255)),
+    (8 / 8, (63 / 255, 0 / 255, 125 / 255)),
+)
 
-gnbu = Colormap((0.000, (247 / 255.0, 252 / 255.0, 240 / 255.0)),
-                (1.000, (8 / 255.0, 64 / 255.0, 129 / 255.0)))
+rdpu = Colormap(
+    (0 / 8, (255 / 255, 247 / 255, 243 / 255)),
+    (1 / 8, (253 / 255, 224 / 255, 221 / 255)),
+    (2 / 8, (252 / 255, 197 / 255, 192 / 255)),
+    (3 / 8, (250 / 255, 159 / 255, 181 / 255)),
+    (4 / 8, (247 / 255, 104 / 255, 161 / 255)),
+    (5 / 8, (221 / 255, 52 / 255, 151 / 255)),
+    (6 / 8, (174 / 255, 1 / 255, 126 / 255)),
+    (7 / 8, (122 / 255, 1 / 255, 119 / 255)),
+    (8 / 8, (73 / 255, 0 / 255, 106 / 255)),
+)
 
-# OrRd
+reds = Colormap(
+    (0 / 8, (255 / 255, 245 / 255, 240 / 255)),
+    (1 / 8, (254 / 255, 224 / 255, 210 / 255)),
+    (2 / 8, (252 / 255, 187 / 255, 161 / 255)),
+    (3 / 8, (252 / 255, 146 / 255, 114 / 255)),
+    (4 / 8, (251 / 255, 106 / 255, 74 / 255)),
+    (5 / 8, (239 / 255, 59 / 255, 44 / 255)),
+    (6 / 8, (203 / 255, 24 / 255, 29 / 255)),
+    (7 / 8, (165 / 255, 15 / 255, 21 / 255)),
+    (8 / 8, (103 / 255, 0 / 255, 13 / 255)),
+)
 
-orrd = Colormap((0.000, (255 / 255.0, 247 / 255.0, 236 / 255.0)),
-                (1.000, (127 / 255.0, 0.0, 0.0)))
+ylgn = Colormap(
+    (0 / 8, (255 / 255, 255 / 255, 229 / 255)),
+    (1 / 8, (247 / 255, 252 / 255, 185 / 255)),
+    (2 / 8, (217 / 255, 240 / 255, 163 / 255)),
+    (3 / 8, (173 / 255, 221 / 255, 142 / 255)),
+    (4 / 8, (120 / 255, 198 / 255, 121 / 255)),
+    (5 / 8, (65 / 255, 171 / 255, 93 / 255)),
+    (6 / 8, (35 / 255, 132 / 255, 67 / 255)),
+    (7 / 8, (0 / 255, 104 / 255, 55 / 255)),
+    (8 / 8, (0 / 255, 69 / 255, 41 / 255)),
+)
 
-# PuBu
+ylgnbu = Colormap(
+    (0 / 8, (255 / 255, 255 / 255, 217 / 255)),
+    (1 / 8, (237 / 255, 248 / 255, 177 / 255)),
+    (2 / 8, (199 / 255, 233 / 255, 180 / 255)),
+    (3 / 8, (127 / 255, 205 / 255, 187 / 255)),
+    (4 / 8, (65 / 255, 182 / 255, 196 / 255)),
+    (5 / 8, (29 / 255, 145 / 255, 192 / 255)),
+    (6 / 8, (34 / 255, 94 / 255, 168 / 255)),
+    (7 / 8, (37 / 255, 52 / 255, 148 / 255)),
+    (8 / 8, (8 / 255, 29 / 255, 88 / 255)),
+)
 
-pubu = Colormap((0.000, (1.0, 247 / 255.0, 251 / 255.0)),
-                (0.500, (116 / 255.0, 169 / 255.0, 207 / 255.0)),
-                (1.000, (2 / 255.0, 56 / 255.0, 88 / 255.0)))
+ylorbr = Colormap(
+    (0 / 8, (255 / 255, 255 / 255, 229 / 255)),
+    (1 / 8, (255 / 255, 247 / 255, 188 / 255)),
+    (2 / 8, (254 / 255, 227 / 255, 145 / 255)),
+    (3 / 8, (254 / 255, 196 / 255, 79 / 255)),
+    (4 / 8, (254 / 255, 153 / 255, 41 / 255)),
+    (5 / 8, (236 / 255, 112 / 255, 20 / 255)),
+    (6 / 8, (204 / 255, 76 / 255, 2 / 255)),
+    (7 / 8, (153 / 255, 52 / 255, 4 / 255)),
+    (8 / 8, (102 / 255, 37 / 255, 6 / 255)),
+)
 
-# PuBuGn
+ylorrd = Colormap(
+    (0 / 7, (255 / 255, 255 / 255, 204 / 255)),
+    (1 / 7, (255 / 255, 237 / 255, 160 / 255)),
+    (2 / 7, (254 / 255, 217 / 255, 118 / 255)),
+    (3 / 7, (254 / 255, 178 / 255, 76 / 255)),
+    (4 / 7, (253 / 255, 141 / 255, 60 / 255)),
+    (5 / 7, (252 / 255, 78 / 255, 42 / 255)),
+    (6 / 7, (227 / 255, 26 / 255, 28 / 255)),
+    (7 / 7, (177 / 255, 0 / 255, 38 / 255)),
+)
 
-pubugn = Colormap((0.000, (1.0, 247 / 255.0, 251 / 255.0)),
-                  (0.500, (103 / 255.0, 169 / 255.0, 207 / 255.0)),
-                  (1.000, (1 / 255.0, 70 / 255.0, 54 / 255.0)))
+sequential_colormaps = {
+    "blues": blues,
+    "bugn": bugn,
+    "bupu": bupu,
+    "gnbu": gnbu,
+    "greens": greens,
+    "greys": greys,
+    "oranges": oranges,
+    "orrd": orrd,
+    "pubu": pubu,
+    "pubugn": pubugn,
+    "purd": purd,
+    "purples": purples,
+    "rdpu": rdpu,
+    "reds": reds,
+    "ylgn": ylgn,
+    "ylgnbu": ylgnbu,
+    "ylorbr": ylorbr,
+    "ylorrd": ylorrd,
+}
 
-# PuRd
+# * Diverging Colormaps *
 
-purd = Colormap((0.000, (247 / 255.0, 244 / 255.0, 249 / 255.0)),
-                (1.000, (103 / 255.0, 0.0, 31 / 255.0)))
+brbg = Colormap(
+    (0 / 10, (84 / 255, 48 / 255, 5 / 255)),
+    (1 / 10, (140 / 255, 81 / 255, 10 / 255)),
+    (2 / 10, (191 / 255, 129 / 255, 45 / 255)),
+    (3 / 10, (223 / 255, 194 / 255, 125 / 255)),
+    (4 / 10, (246 / 255, 232 / 255, 195 / 255)),
+    (5 / 10, (245 / 255, 245 / 255, 245 / 255)),
+    (6 / 10, (199 / 255, 234 / 255, 229 / 255)),
+    (7 / 10, (128 / 255, 205 / 255, 193 / 255)),
+    (8 / 10, (53 / 255, 151 / 255, 143 / 255)),
+    (9 / 10, (1 / 255, 102 / 255, 94 / 255)),
+    (10 / 10, (0 / 255, 60 / 255, 48 / 255)),
+)
 
-# RdPu
+piyg = Colormap(
+    (0 / 10, (142 / 255, 1 / 255, 82 / 255)),
+    (1 / 10, (197 / 255, 27 / 255, 125 / 255)),
+    (2 / 10, (222 / 255, 119 / 255, 174 / 255)),
+    (3 / 10, (241 / 255, 182 / 255, 218 / 255)),
+    (4 / 10, (253 / 255, 224 / 255, 239 / 255)),
+    (5 / 10, (247 / 255, 247 / 255, 247 / 255)),
+    (6 / 10, (230 / 255, 245 / 255, 208 / 255)),
+    (7 / 10, (184 / 255, 225 / 255, 134 / 255)),
+    (8 / 10, (127 / 255, 188 / 255, 65 / 255)),
+    (9 / 10, (77 / 255, 146 / 255, 33 / 255)),
+    (10 / 10, (39 / 255, 100 / 255, 25 / 255)),
+)
 
-rdpu = Colormap((0.000, (1.0, 247 / 255.0, 243 / 255.0)),
-                (1.000, (73 / 255.0, 0.0, 106 / 255.0)))
+prgn = Colormap(
+    (0 / 10, (64 / 255, 0 / 255, 75 / 255)),
+    (1 / 10, (118 / 255, 42 / 255, 131 / 255)),
+    (2 / 10, (153 / 255, 112 / 255, 171 / 255)),
+    (3 / 10, (194 / 255, 165 / 255, 207 / 255)),
+    (4 / 10, (231 / 255, 212 / 255, 232 / 255)),
+    (5 / 10, (247 / 255, 247 / 255, 247 / 255)),
+    (6 / 10, (217 / 255, 240 / 255, 211 / 255)),
+    (7 / 10, (166 / 255, 219 / 255, 160 / 255)),
+    (8 / 10, (90 / 255, 174 / 255, 97 / 255)),
+    (9 / 10, (27 / 255, 120 / 255, 55 / 255)),
+    (10 / 10, (0 / 255, 68 / 255, 27 / 255)),
+)
 
-# YlGn
+puor = Colormap(
+    (0 / 10, (127 / 255, 59 / 255, 8 / 255)),
+    (1 / 10, (179 / 255, 88 / 255, 6 / 255)),
+    (2 / 10, (224 / 255, 130 / 255, 20 / 255)),
+    (3 / 10, (253 / 255, 184 / 255, 99 / 255)),
+    (4 / 10, (254 / 255, 224 / 255, 182 / 255)),
+    (5 / 10, (247 / 255, 247 / 255, 247 / 255)),
+    (6 / 10, (216 / 255, 218 / 255, 235 / 255)),
+    (7 / 10, (178 / 255, 171 / 255, 210 / 255)),
+    (8 / 10, (128 / 255, 115 / 255, 172 / 255)),
+    (9 / 10, (84 / 255, 39 / 255, 136 / 255)),
+    (10 / 10, (45 / 255, 0 / 255, 75 / 255)),
+)
 
-ylgn = Colormap((0.000, (1.0, 1.0, 229 / 255.0)),
-                (1.000, (0.0, 69 / 255.0, 41 / 255.0)))
+rdbu = Colormap(
+    (0 / 10, (103 / 255, 0 / 255, 31 / 255)),
+    (1 / 10, (178 / 255, 24 / 255, 43 / 255)),
+    (2 / 10, (214 / 255, 96 / 255, 77 / 255)),
+    (3 / 10, (244 / 255, 165 / 255, 130 / 255)),
+    (4 / 10, (253 / 255, 219 / 255, 199 / 255)),
+    (5 / 10, (247 / 255, 247 / 255, 247 / 255)),
+    (6 / 10, (209 / 255, 229 / 255, 240 / 255)),
+    (7 / 10, (146 / 255, 197 / 255, 222 / 255)),
+    (8 / 10, (67 / 255, 147 / 255, 195 / 255)),
+    (9 / 10, (33 / 255, 102 / 255, 172 / 255)),
+    (10 / 10, (5 / 255, 48 / 255, 97 / 255)),
+)
 
-# YlGnBu
+rdgy = Colormap(
+    (0 / 10, (103 / 255, 0 / 255, 31 / 255)),
+    (1 / 10, (178 / 255, 24 / 255, 43 / 255)),
+    (2 / 10, (214 / 255, 96 / 255, 77 / 255)),
+    (3 / 10, (244 / 255, 165 / 255, 130 / 255)),
+    (4 / 10, (253 / 255, 219 / 255, 199 / 255)),
+    (5 / 10, (255 / 255, 255 / 255, 255 / 255)),
+    (6 / 10, (224 / 255, 224 / 255, 224 / 255)),
+    (7 / 10, (186 / 255, 186 / 255, 186 / 255)),
+    (8 / 10, (135 / 255, 135 / 255, 135 / 255)),
+    (9 / 10, (77 / 255, 77 / 255, 77 / 255)),
+    (10 / 10, (26 / 255, 26 / 255, 26 / 255)),
+)
 
-ylgnbu = Colormap((0.000, (1.0, 1.0, 217 / 255.0)),
-                  (0.500, (65 / 255.0, 182 / 255.0, 196 / 255.0)),
-                  (1.000, (8 / 255.0, 29 / 255.0, 88 / 255.0)))
+rdylbu = Colormap(
+    (0 / 10, (165 / 255, 0 / 255, 38 / 255)),
+    (1 / 10, (215 / 255, 48 / 255, 39 / 255)),
+    (2 / 10, (244 / 255, 109 / 255, 67 / 255)),
+    (3 / 10, (253 / 255, 174 / 255, 97 / 255)),
+    (4 / 10, (254 / 255, 224 / 255, 144 / 255)),
+    (5 / 10, (255 / 255, 255 / 255, 191 / 255)),
+    (6 / 10, (224 / 255, 243 / 255, 248 / 255)),
+    (7 / 10, (171 / 255, 217 / 255, 233 / 255)),
+    (8 / 10, (116 / 255, 173 / 255, 209 / 255)),
+    (9 / 10, (69 / 255, 117 / 255, 180 / 255)),
+    (10 / 10, (49 / 255, 54 / 255, 149 / 255)),
+)
 
-# YlOrBr
+rdylgn = Colormap(
+    (0 / 10, (165 / 255, 0 / 255, 38 / 255)),
+    (1 / 10, (215 / 255, 48 / 255, 39 / 255)),
+    (2 / 10, (244 / 255, 109 / 255, 67 / 255)),
+    (3 / 10, (253 / 255, 174 / 255, 97 / 255)),
+    (4 / 10, (254 / 255, 224 / 255, 139 / 255)),
+    (5 / 10, (255 / 255, 255 / 255, 191 / 255)),
+    (6 / 10, (217 / 255, 239 / 255, 139 / 255)),
+    (7 / 10, (166 / 255, 217 / 255, 106 / 255)),
+    (8 / 10, (102 / 255, 189 / 255, 99 / 255)),
+    (9 / 10, (26 / 255, 152 / 255, 80 / 255)),
+    (10 / 10, (0 / 255, 104 / 255, 55 / 255)),
+)
 
-ylorbr = Colormap((0.000, (1.0, 1.0, 229 / 255.0)),
-                  (0.500, (254 / 255.0, 153 / 255.0, 41 / 255.0)),
-                  (1.000, (102 / 255.0, 37 / 255.0, 6 / 255.0)))
+spectral = Colormap(
+    (0 / 10, (158 / 255, 1 / 255, 66 / 255)),
+    (1 / 10, (213 / 255, 62 / 255, 79 / 255)),
+    (2 / 10, (244 / 255, 109 / 255, 67 / 255)),
+    (3 / 10, (253 / 255, 174 / 255, 97 / 255)),
+    (4 / 10, (254 / 255, 224 / 255, 139 / 255)),
+    (5 / 10, (255 / 255, 255 / 255, 191 / 255)),
+    (6 / 10, (230 / 255, 245 / 255, 152 / 255)),
+    (7 / 10, (171 / 255, 221 / 255, 164 / 255)),
+    (8 / 10, (102 / 255, 194 / 255, 165 / 255)),
+    (9 / 10, (50 / 255, 136 / 255, 189 / 255)),
+    (10 / 10, (94 / 255, 79 / 255, 162 / 255)),
+)
 
-# YlOrRd
+diverging_colormaps = {
+    "brbg": brbg,
+    "piyg": piyg,
+    "prgn": prgn,
+    "puor": puor,
+    "rdbu": rdbu,
+    "rdgy": rdgy,
+    "rdylbu": rdylbu,
+    "rdylgn": rdylgn,
+    "spectral": spectral,
+}
 
-ylorrd = Colormap((0.000, (1.0, 1.0, 204 / 255.0)),
-                  (0.500, (254 / 255.0, 141 / 255.0, 60 / 255.0)),
-                  (1.000, (128 / 255.0, 0.0, 38 / 255.0)))
+# * Qualitative Colormaps *
 
-sequential_colormaps = [blues, greens, greys, oranges, purples, reds,
-                        bugn, bupu, gnbu, orrd, pubu, pubugn, purd, rdpu,
-                        ylgn, ylgnbu, ylorbr, ylorrd]
+accent = Colormap(
+    (0, (127 / 255, 201 / 255, 127 / 255)),
+    (1, (190 / 255, 174 / 255, 212 / 255)),
+    (2, (253 / 255, 192 / 255, 134 / 255)),
+    (3, (255 / 255, 255 / 255, 153 / 255)),
+    (4, (56 / 255, 108 / 255, 176 / 255)),
+    (5, (240 / 255, 2 / 255, 127 / 255)),
+    (6, (191 / 255, 91 / 255, 23 / 255)),
+    (7, (102 / 255, 102 / 255, 102 / 255)),
+)
 
-# * Diverging *
+dark2 = Colormap(
+    (0, (27 / 255, 158 / 255, 119 / 255)),
+    (1, (217 / 255, 95 / 255, 2 / 255)),
+    (2, (117 / 255, 112 / 255, 179 / 255)),
+    (3, (231 / 255, 41 / 255, 138 / 255)),
+    (4, (102 / 255, 166 / 255, 30 / 255)),
+    (5, (230 / 255, 171 / 255, 2 / 255)),
+    (6, (166 / 255, 118 / 255, 29 / 255)),
+    (7, (102 / 255, 102 / 255, 102 / 255)),
+)
 
-brbg = Colormap((0.0, (84 / 255.0, 48 / 255.0, 5 / 255.0)),
-                (0.1, (140 / 255.0, 81 / 255.0, 10 / 255.0)),
-                (0.2, (191 / 255.0, 129 / 255.0, 45 / 255.0)),
-                (0.3, (223 / 255.0, 194 / 255.0, 125 / 255.0)),
-                (0.4, (246 / 255.0, 232 / 255.0, 195 / 255.0)),
-                (0.5, (245 / 255.0, 245 / 255.0, 245 / 255.0)),
-                (0.6, (199 / 255.0, 234 / 255.0, 229 / 255.0)),
-                (0.7, (128 / 255.0, 205 / 255.0, 193 / 255.0)),
-                (0.8, (53 / 255.0, 151 / 255.0, 143 / 255.0)),
-                (0.9, (1 / 255.0, 102 / 255.0, 94 / 255.0)),
-                (1.0, (0 / 255.0, 60 / 255.0, 48 / 255.0)))
+paired = Colormap(
+    (0, (166 / 255, 206 / 255, 227 / 255)),
+    (1, (31 / 255, 120 / 255, 180 / 255)),
+    (2, (178 / 255, 223 / 255, 138 / 255)),
+    (3, (51 / 255, 160 / 255, 44 / 255)),
+    (4, (251 / 255, 154 / 255, 153 / 255)),
+    (5, (227 / 255, 26 / 255, 28 / 255)),
+    (6, (253 / 255, 191 / 255, 111 / 255)),
+    (7, (255 / 255, 127 / 255, 0 / 255)),
+    (8, (202 / 255, 178 / 255, 214 / 255)),
+    (9, (106 / 255, 61 / 255, 154 / 255)),
+    (10, (255 / 255, 255 / 255, 153 / 255)),
+    (11, (177 / 255, 89 / 255, 40 / 255)),
+)
 
-piyg = Colormap((0.0, (142 / 255.0, 1 / 255.0, 82 / 255.0)),
-                (0.1, (197 / 255.0, 27 / 255.0, 125 / 255.0)),
-                (0.2, (222 / 255.0, 119 / 255.0, 174 / 255.0)),
-                (0.3, (241 / 255.0, 182 / 255.0, 218 / 255.0)),
-                (0.4, (253 / 255.0, 224 / 255.0, 239 / 255.0)),
-                (0.5, (247 / 255.0, 247 / 255.0, 247 / 255.0)),
-                (0.6, (230 / 255.0, 245 / 255.0, 208 / 255.0)),
-                (0.7, (184 / 255.0, 225 / 255.0, 134 / 255.0)),
-                (0.8, (127 / 255.0, 188 / 255.0, 65 / 255.0)),
-                (0.9, (77 / 255.0, 146 / 255.0, 33 / 255.0)),
-                (1.0, (39 / 255.0, 100 / 255.0, 25 / 255.0)))
+pastel1 = Colormap(
+    (0, (251 / 255, 180 / 255, 174 / 255)),
+    (1, (179 / 255, 205 / 255, 227 / 255)),
+    (2, (204 / 255, 235 / 255, 197 / 255)),
+    (3, (222 / 255, 203 / 255, 228 / 255)),
+    (4, (254 / 255, 217 / 255, 166 / 255)),
+    (5, (255 / 255, 255 / 255, 204 / 255)),
+    (6, (229 / 255, 216 / 255, 189 / 255)),
+    (7, (253 / 255, 218 / 255, 236 / 255)),
+    (8, (242 / 255, 242 / 255, 242 / 255)),
+)
 
-prgn = Colormap((0.0, (64 / 255.0, 0 / 255.0, 75 / 255.0)),
-                (0.1, (118 / 255.0, 42 / 255.0, 131 / 255.0)),
-                (0.2, (153 / 255.0, 112 / 255.0, 171 / 255.0)),
-                (0.3, (194 / 255.0, 165 / 255.0, 207 / 255.0)),
-                (0.4, (231 / 255.0, 212 / 255.0, 232 / 255.0)),
-                (0.5, (247 / 255.0, 247 / 255.0, 247 / 255.0)),
-                (0.6, (217 / 255.0, 240 / 255.0, 211 / 255.0)),
-                (0.7, (166 / 255.0, 219 / 255.0, 160 / 255.0)),
-                (0.8, (90 / 255.0, 174 / 255.0, 97 / 255.0)),
-                (0.9, (27 / 255.0, 120 / 255.0, 55 / 255.0)),
-                (1.0, (0 / 255.0, 68 / 255.0, 27 / 255.0)))
+pastel2 = Colormap(
+    (0, (179 / 255, 226 / 255, 205 / 255)),
+    (1, (253 / 255, 205 / 255, 172 / 255)),
+    (2, (203 / 255, 213 / 255, 232 / 255)),
+    (3, (244 / 255, 202 / 255, 228 / 255)),
+    (4, (230 / 255, 245 / 255, 201 / 255)),
+    (5, (255 / 255, 242 / 255, 174 / 255)),
+    (6, (241 / 255, 226 / 255, 204 / 255)),
+    (7, (204 / 255, 204 / 255, 204 / 255)),
+)
 
-puor = Colormap((0.0, (127 / 255.0, 59 / 255.0, 8 / 255.0)),
-                (0.1, (179 / 255.0, 88 / 255.0, 6 / 255.0)),
-                (0.2, (224 / 255.0, 130 / 255.0, 20 / 255.0)),
-                (0.3, (253 / 255.0, 184 / 255.0, 99 / 255.0)),
-                (0.4, (254 / 255.0, 224 / 255.0, 182 / 255.0)),
-                (0.5, (247 / 255.0, 247 / 255.0, 247 / 255.0)),
-                (0.6, (216 / 255.0, 218 / 255.0, 235 / 255.0)),
-                (0.7, (178 / 255.0, 171 / 255.0, 210 / 255.0)),
-                (0.8, (128 / 255.0, 115 / 255.0, 172 / 255.0)),
-                (0.9, (84 / 255.0, 39 / 255.0, 136 / 255.0)),
-                (1.0, (45 / 255.0, 0 / 255.0, 75 / 255.0)))
+set1 = Colormap(
+    (0, (228 / 255, 26 / 255, 28 / 255)),
+    (1, (55 / 255, 126 / 255, 184 / 255)),
+    (2, (77 / 255, 175 / 255, 74 / 255)),
+    (3, (152 / 255, 78 / 255, 163 / 255)),
+    (4, (255 / 255, 127 / 255, 0 / 255)),
+    (5, (255 / 255, 255 / 255, 51 / 255)),
+    (6, (166 / 255, 86 / 255, 40 / 255)),
+    (7, (247 / 255, 129 / 255, 191 / 255)),
+    (8, (153 / 255, 153 / 255, 153 / 255)),
+)
 
-rdbu = Colormap((0.0, (103 / 255.0, 0 / 255.0, 31 / 255.0)),
-                (0.1, (178 / 255.0, 24 / 255.0, 43 / 255.0)),
-                (0.2, (214 / 255.0, 96 / 255.0, 77 / 255.0)),
-                (0.3, (244 / 255.0, 165 / 255.0, 130 / 255.0)),
-                (0.4, (253 / 255.0, 219 / 255.0, 199 / 255.0)),
-                (0.5, (247 / 255.0, 247 / 255.0, 247 / 255.0)),
-                (0.6, (209 / 255.0, 229 / 255.0, 240 / 255.0)),
-                (0.7, (146 / 255.0, 197 / 255.0, 222 / 255.0)),
-                (0.8, (67 / 255.0, 147 / 255.0, 195 / 255.0)),
-                (0.9, (33 / 255.0, 102 / 255.0, 172 / 255.0)),
-                (1.0, (5 / 255.0, 48 / 255.0, 97 / 255.0)))
+set2 = Colormap(
+    (0, (102 / 255, 194 / 255, 165 / 255)),
+    (1, (252 / 255, 141 / 255, 98 / 255)),
+    (2, (141 / 255, 160 / 255, 203 / 255)),
+    (3, (231 / 255, 138 / 255, 195 / 255)),
+    (4, (166 / 255, 216 / 255, 84 / 255)),
+    (5, (255 / 255, 217 / 255, 47 / 255)),
+    (6, (229 / 255, 196 / 255, 148 / 255)),
+    (7, (179 / 255, 179 / 255, 179 / 255)),
+)
 
-rdgy = Colormap((0.0, (103 / 255.0, 0 / 255.0, 31 / 255.0)),
-                (0.1, (178 / 255.0, 24 / 255.0, 43 / 255.0)),
-                (0.2, (214 / 255.0, 96 / 255.0, 77 / 255.0)),
-                (0.3, (244 / 255.0, 165 / 255.0, 130 / 255.0)),
-                (0.4, (253 / 255.0, 219 / 255.0, 199 / 255.0)),
-                (0.5, (255 / 255.0, 255 / 255.0, 255 / 255.0)),
-                (0.6, (224 / 255.0, 224 / 255.0, 224 / 255.0)),
-                (0.7, (186 / 255.0, 186 / 255.0, 186 / 255.0)),
-                (0.8, (135 / 255.0, 135 / 255.0, 135 / 255.0)),
-                (0.9, (77 / 255.0, 77 / 255.0, 77 / 255.0)),
-                (1.0, (26 / 255.0, 26 / 255.0, 26 / 255.0)))
+set3 = Colormap(
+    (0, (141 / 255, 211 / 255, 199 / 255)),
+    (1, (255 / 255, 255 / 255, 179 / 255)),
+    (2, (190 / 255, 186 / 255, 218 / 255)),
+    (3, (251 / 255, 128 / 255, 114 / 255)),
+    (4, (128 / 255, 177 / 255, 211 / 255)),
+    (5, (253 / 255, 180 / 255, 98 / 255)),
+    (6, (179 / 255, 222 / 255, 105 / 255)),
+    (7, (252 / 255, 205 / 255, 229 / 255)),
+    (8, (217 / 255, 217 / 255, 217 / 255)),
+    (9, (188 / 255, 128 / 255, 189 / 255)),
+    (10, (204 / 255, 235 / 255, 197 / 255)),
+    (11, (255 / 255, 237 / 255, 111 / 255)),
+)
 
-rdylbu = Colormap((0.0, (165 / 255.0, 0 / 255.0, 38 / 255.0)),
-                  (0.1, (215 / 255.0, 48 / 255.0, 39 / 255.0)),
-                  (0.2, (244 / 255.0, 109 / 255.0, 67 / 255.0)),
-                  (0.3, (253 / 255.0, 174 / 255.0, 97 / 255.0)),
-                  (0.4, (254 / 255.0, 224 / 255.0, 144 / 255.0)),
-                  (0.5, (255 / 255.0, 255 / 255.0, 191 / 255.0)),
-                  (0.6, (224 / 255.0, 243 / 255.0, 248 / 255.0)),
-                  (0.7, (171 / 255.0, 217 / 255.0, 233 / 255.0)),
-                  (0.8, (116 / 255.0, 173 / 255.0, 209 / 255.0)),
-                  (0.9, (69 / 255.0, 117 / 255.0, 180 / 255.0)),
-                  (1.0, (49 / 255.0, 54 / 255.0, 149 / 255.0)))
-
-rdylgn = Colormap((0.0, (165 / 255.0, 0 / 255.0, 38 / 255.0)),
-                  (0.1, (215 / 255.0, 48 / 255.0, 39 / 255.0)),
-                  (0.2, (244 / 255.0, 109 / 255.0, 67 / 255.0)),
-                  (0.3, (253 / 255.0, 174 / 255.0, 97 / 255.0)),
-                  (0.4, (254 / 255.0, 224 / 255.0, 139 / 255.0)),
-                  (0.5, (255 / 255.0, 255 / 255.0, 191 / 255.0)),
-                  (0.6, (217 / 255.0, 239 / 255.0, 139 / 255.0)),
-                  (0.7, (166 / 255.0, 217 / 255.0, 106 / 255.0)),
-                  (0.8, (102 / 255.0, 189 / 255.0, 99 / 255.0)),
-                  (0.9, (26 / 255.0, 152 / 255.0, 80 / 255.0)),
-                  (1.0, (0 / 255.0, 104 / 255.0, 55 / 255.0)))
-
-spectral = Colormap((0.0, (158 / 255.0, 1 / 255.0, 66 / 255.0)),
-                    (0.1, (213 / 255.0, 62 / 255.0, 79 / 255.0)),
-                    (0.2, (244 / 255.0, 109 / 255.0, 67 / 255.0)),
-                    (0.3, (253 / 255.0, 174 / 255.0, 97 / 255.0)),
-                    (0.4, (254 / 255.0, 224 / 255.0, 139 / 255.0)),
-                    (0.5, (255 / 255.0, 255 / 255.0, 191 / 255.0)),
-                    (0.6, (230 / 255.0, 245 / 255.0, 152 / 255.0)),
-                    (0.7, (171 / 255.0, 221 / 255.0, 164 / 255.0)),
-                    (0.8, (102 / 255.0, 194 / 255.0, 165 / 255.0)),
-                    (0.9, (50 / 255.0, 136 / 255.0, 189 / 255.0)),
-                    (1.0, (94 / 255.0, 79 / 255.0, 162 / 255.0)))
-
-diverging_colormaps = [brbg, piyg, prgn, puor, rdbu, rdgy, rdylbu, rdylgn,
-                       spectral]
-
-# * qualitative colormaps *
-
-set1 = Colormap((0, (228 / 255.0, 26 / 255.0, 28 / 255.0)),
-                (1, (55 / 255.0, 126 / 255.0, 184 / 255.0)),
-                (2, (77 / 255.0, 175 / 255.0, 74 / 255.0)),
-                (3, (152 / 255.0, 78 / 255.0, 163 / 255.0)),
-                (4, (255 / 255.0, 127 / 255.0, 0 / 255.0)),
-                (5, (255 / 255.0, 255 / 255.0, 51 / 255.0)),
-                (6, (166 / 255.0, 86 / 255.0, 40 / 255.0)),
-                (7, (247 / 255.0, 129 / 255.0, 191 / 255.0)),
-                (8, (153 / 255.0, 153 / 255.0, 153 / 255.0)))
-
-set2 = Colormap((0, (102 / 255.0, 194 / 255.0, 165 / 255.0)),
-                (1, (252 / 255.0, 141 / 255.0, 98 / 255.0)),
-                (2, (141 / 255.0, 160 / 255.0, 203 / 255.0)),
-                (3, (231 / 255.0, 138 / 255.0, 195 / 255.0)),
-                (4, (166 / 255.0, 216 / 255.0, 84 / 255.0)),
-                (5, (255 / 255.0, 217 / 255.0, 47 / 255.0)),
-                (6, (229 / 255.0, 196 / 255.0, 148 / 255.0)),
-                (7, (179 / 255.0, 179 / 255.0, 179 / 255.0)))
-
-set3 = Colormap((0, (141 / 255.0, 211 / 255.0, 199 / 255.0)),
-                (1, (255 / 255.0, 255 / 255.0, 179 / 255.0)),
-                (2, (190 / 255.0, 186 / 255.0, 218 / 255.0)),
-                (3, (251 / 255.0, 128 / 255.0, 114 / 255.0)),
-                (4, (128 / 255.0, 177 / 255.0, 211 / 255.0)),
-                (5, (253 / 255.0, 180 / 255.0, 98 / 255.0)),
-                (6, (179 / 255.0, 222 / 255.0, 105 / 255.0)),
-                (7, (252 / 255.0, 205 / 255.0, 229 / 255.0)),
-                (8, (217 / 255.0, 217 / 255.0, 217 / 255.0)),
-                (9, (188 / 255.0, 128 / 255.0, 189 / 255.0)),
-                (10, (204 / 255.0, 235 / 255.0, 197 / 255.0)),
-                (11, (255 / 255.0, 237 / 255.0, 111 / 255.0)))
-
-paired = Colormap((0, (166 / 255.0, 206 / 255.0, 227 / 255.0)),
-                  (1, (31 / 255.0, 120 / 255.0, 180 / 255.0)),
-                  (2, (178 / 255.0, 223 / 255.0, 138 / 255.0)),
-                  (3, (51 / 255.0, 160 / 255.0, 44 / 255.0)),
-                  (4, (251 / 255.0, 154 / 255.0, 153 / 255.0)),
-                  (5, (227 / 255.0, 26 / 255.0, 28 / 255.0)),
-                  (6, (253 / 255.0, 191 / 255.0, 111 / 255.0)),
-                  (7, (255 / 255.0, 127 / 255.0, 0 / 255.0)),
-                  (8, (202 / 255.0, 178 / 255.0, 214 / 255.0)),
-                  (9, (106 / 255.0, 61 / 255.0, 154 / 255.0)),
-                  (10, (255 / 255.0, 255 / 255.0, 153 / 255.0)),
-                  (11, (177 / 255.0, 89 / 255.0, 40 / 255.0)))
-
-accent = Colormap((0, (127 / 255.0, 201 / 255.0, 127 / 255.0)),
-                  (1, (190 / 255.0, 174 / 255.0, 212 / 255.0)),
-                  (2, (253 / 255.0, 192 / 255.0, 134 / 255.0)),
-                  (3, (255 / 255.0, 255 / 255.0, 153 / 255.0)),
-                  (4, (56 / 255.0, 108 / 255.0, 176 / 255.0)),
-                  (5, (240 / 255.0, 2 / 255.0, 127 / 255.0)),
-                  (6, (191 / 255.0, 91 / 255.0, 23 / 255.0)),
-                  (7, (102 / 255.0, 102 / 255.0, 102 / 255.0)))
-
-dark2 = Colormap((0, (27 / 255.0, 158 / 255.0, 119 / 255.0)),
-                 (1, (217 / 255.0, 95 / 255.0, 2 / 255.0)),
-                 (2, (117 / 255.0, 112 / 255.0, 179 / 255.0)),
-                 (3, (231 / 255.0, 41 / 255.0, 138 / 255.0)),
-                 (4, (102 / 255.0, 166 / 255.0, 30 / 255.0)),
-                 (5, (230 / 255.0, 171 / 255.0, 2 / 255.0)),
-                 (6, (166 / 255.0, 118 / 255.0, 29 / 255.0)),
-                 (7, (102 / 255.0, 102 / 255.0, 102 / 255.0)))
-
-pastel1 = Colormap((0, (251 / 255.0, 180 / 255.0, 174 / 255.0)),
-                   (1, (179 / 255.0, 205 / 255.0, 227 / 255.0)),
-                   (2, (204 / 255.0, 235 / 255.0, 197 / 255.0)),
-                   (3, (222 / 255.0, 203 / 255.0, 228 / 255.0)),
-                   (4, (254 / 255.0, 217 / 255.0, 166 / 255.0)),
-                   (5, (255 / 255.0, 255 / 255.0, 204 / 255.0)),
-                   (6, (229 / 255.0, 216 / 255.0, 189 / 255.0)),
-                   (7, (253 / 255.0, 218 / 255.0, 236 / 255.0)),
-                   (8, (242 / 255.0, 242 / 255.0, 242 / 255.0)))
-
-pastel2 = Colormap((0, (179 / 255.0, 226 / 255.0, 205 / 255.0)),
-                   (1, (253 / 255.0, 205 / 255.0, 172 / 255.0)),
-                   (2, (203 / 255.0, 213 / 255.0, 232 / 255.0)),
-                   (3, (244 / 255.0, 202 / 255.0, 228 / 255.0)),
-                   (4, (230 / 255.0, 245 / 255.0, 201 / 255.0)),
-                   (5, (255 / 255.0, 242 / 255.0, 174 / 255.0)),
-                   (6, (241 / 255.0, 226 / 255.0, 204 / 255.0)),
-                   (7, (204 / 255.0, 204 / 255.0, 204 / 255.0)))
-
-qualitative_colormaps = [set1, set2, set3,
-                         paired, accent, dark2,
-                         pastel1, pastel2]
+qualitative_colormaps = {
+    "accent": accent,
+    "dark2": dark2,
+    "paired": paired,
+    "pastel1": pastel1,
+    "pastel2": pastel2,
+    "set1": set1,
+    "set2": set2,
+    "set3": set3,
+}
 
 
 def colorbar(height, length, colormap, category=False):
